Range-v3: ranges::v3::view::repeat_n_fn Struct Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Synopsis of methods | Public Member Functions | List of all members
ranges::v3::view::repeat_n_fn Struct Reference

## Synopsis of methods
constexpr repeat_n_fn | repeat_n {}

## Public Member Functions
template<typename Val , requires = (SemiRegular<Val>())>
repeat_n_view< Val > | operator() (Val value, std::ptrdiff_t n) const